struct PromiseKey(*const Promise);Tuple Fields
0: *const PromiseTrait Implementations
Sourceimpl Clone for PromiseKey
impl Clone for PromiseKey
Sourcefn clone(&self) -> PromiseKey
fn clone(&self) -> PromiseKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Hash for PromiseKey
impl Hash for PromiseKey
Sourceimpl PartialEq for PromiseKey
impl PartialEq for PromiseKey
Sourcefn eq(&self, other: &PromiseKey) -> bool
fn eq(&self, other: &PromiseKey) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for PromiseKey
impl Eq for PromiseKey
impl Send for PromiseKey
Safety
PromiseKey is only ever used for comparisons between keys. Its value is never read.
impl StructuralPartialEq for PromiseKey