[][src]Struct script::dom::bindings::refcounted::TrustedPromise

pub struct TrustedPromise {
    dom_object: *const Promise,
    owner_thread: *const c_void,
}

A safe wrapper around a DOM Promise object that can be shared among threads for use in asynchronous operations. The underlying DOM object is guaranteed to live at least as long as the last outstanding TrustedPromise instance. These values cannot be cloned, only created from existing Rc values.

Fields

dom_object: *const Promiseowner_thread: *const c_void

Implementations

impl TrustedPromise[src]

pub fn new(promise: Rc<Promise>) -> TrustedPromise[src]

Create a new TrustedPromise instance from an existing DOM object. The object will be prevented from being GCed for the duration of the resulting TrustedPromise object's lifetime.

pub fn root(self) -> Rc<Promise>[src]

Obtain a usable DOM Promise from a pinned TrustedPromise value. Fails if used on a different thread than the original value from which this TrustedPromise was obtained.

pub fn reject_task(self, error: Error) -> impl TaskOnce[src]

A task which will reject the promise.

pub fn resolve_task<T>(self, value: T) -> impl TaskOnce where
    T: ToJSValConvertible + Send
[src]

A task which will resolve the promise.